==> icedove-dispmua_1.6.3.orig.tar.gz: icedove-dispmua-1.6.3/chrome/content/data-62.js <==
dispMUA.arDispMUAAllocation["b"] =
{
  "berlitec massmailer based on phpmailer" : [ "phpmailer.png" , "http://phpmailer.codeworxtech.com/" ] ,
  "beer email by beeradvocate.com" : [ "beeradvocate.png" , "http://beeradvocate.com/" ] ,
  "bynari insight connector" : [ "insight-connector.png" , "http://www.bynari.net/" ] ,
  "blue shield mail server" : [ "tumbleweed.png" , "http://www.tumbleweed.com/" ] ,
  "bueroware mailclient" : [ "softengine.png" , "http://www.softengine.de/" ] ,
  "billing@disputo.com" : [ "disputo_com.png" , "http://www.disputo.com/" ] ,
  "bbsoft mail server" : [ "bbsoft.png" , "http://www.bbsoft.de/" ] ,
  "brezosoft kmailer" : [ "kmailer.png" , "http://www.kmailer.com/" ] ,
  "bookcrossing.com" : [ "bookcrossing.png" , "http://www.bookcrossing.com/" ] ,
  "blue world lasso" : [ "lasso.png" , "http://www.lassosoft.com/" ] ,
  "blue sky factory" : [ "blueskyfactory.png" , "http://www.blueskyfactory.com/" ] ,
  "balticdatacenter" : [ "balticdatacenter.png" , "http://www.balticdatacenter.pl/" ] ,
  "britecastmailer" : [ "britemoon.png" , "http://www.britemoon.com/" ] ,
  "booklooker-mail" : [ "booklooker.png" , "http://www.booklooker.de/" ] ,
  "blizzard mailer" : [ "blizzard.png" , "http://www.blizzard.com/" ] ,
  "benchmail agent" : [ "benchmark.png" , "http://benchmail.benchmark.fr/" ] ,
  "bank of america" : [ "bankofamerica.png" , "https://wealthmanagement.bankofamerica.com/nsm/demo/estatements.html" ] ,
  "bre massmailer" : [ "bre.png" ] ,
  "burgerking.de" : [ "burgerking.png" , "http://www.burgerking.de/" ] ,
  "broadcasthtml" : [ "broadcasthtml.png" , "http://www.mailworkz.com/broadcast.htm" ] ,
  "bronto mail" : [ "brontomail.png" , "http://www.bronto.com/" ] ,
  "bpm beeline" : [ "bpm_beeline.png" , "http://www.bpm.ch/Produkte/beeline" ] ,
  "bplaced.net" : [ "bplaced_net.png" , "http://www.bplaced.net/" ] ,
  "bitdefender" : [ "bitdefender.png" , "http://www.bitdefender.com/" ] ,
  "bluedragon" : [ "bluedragon.png" , "http://www.newatlanta.com/products/bluedragon/" ] ,
  "bestarmail" : [ "willcom.png" , "http://www.willcom-inc.com/" ] ,
  "bee alerts" : [ "bee_alerts.png" ] ,
  "bossmedia" : [ "bossmedia.png" , "http://www.bossmedia.com/" ] ,
  "bofh-mail" : [ "bofhmail.png" ] ,
  "blitzmail" : [ "blitzmail.png" , "http://www.dartmouth.edu/comp/support/library/software/email/blitzmail/" ] ,
  "bigsender" : [ "bigsender.png" , "http://www.craigrichards.com/software/bigsender/" ] ,
  "beos-pynr" : [ "beos.png" , "http://www.beincorporated.com/" ] ,
  "bdoc-edit" : [ "bdoc-edit.png" , "http://www.bdoc.com/" ] ,
  "boldchat" : [ "bold.png" , "http://www.boldchat.com/" ] ,
  "birdigee" : [ "birdigee.png" , "http://www.birdigee.de/newsletter.shtml" ] ,
  "betanews" : [ "betanews.png" ] ,
  "banan.cz" : [ "banan_cz.png" , "http://webmail.banan.cz/" ] ,
  "bluewin" : [ "bluewin_ch.png" , "http://www.bluewin.ch/" ] ,
  "bluetie" : [ "bluetie.png" , "http://www.bluetie.com/" ] ,
  "bloomba" : [ "bloomba.png" , "http://www.statalabs.com/" ] ,
  "blog.de" : [ "blog_de.png" , "http://www.blog.de/" ] ,
  "baur-nl" : [ "baur-nl.png" , "http://www.baur.de/" ] ,
  "basilix" : [ "basilix.png" , "http://www.basilix.org/" ] ,
  "b1gmail" : [ "b1gmail.png" , "http://www.b1g.de/" ] ,
  "biabam" : [ "biabam.png" ] ,
  "bemail" : [ "bemail.png" ] ,
  "becky!" : [ "becky.png" , "http://www.rimarts.co.jp/becky.htm" ] ,
  "boxee" : [ "boxee.png" , "http://www.boxee.tv/" ] ,
  "bmail" : [ "bmail.png" , "http://www.beyondlogic.org/" ] ,
  "barca" : [ "barca.png" , "http://www.pocosystems.com/" ] ,
  "balsa" : [ "balsa.png" , "http://balsa.gnome.org/" ] ,
  "bscw" : [ "bscw.png" , "http://public.bscw.de/" ] ,
  "blat" : [ "blat.png" , "http://www.blat.net/" ] ,
  "bbc" : [ "bbc.png" , "http://www.bbc.co.uk/" ] ,
}

==> icedove-dispmua_1.6.4.3.orig.tar.gz: icedove-dispmua-1.6.4.3/chrome/content/data-62.js <==
dispMUA.arDispMUAAllocation["b"] =
{
  "berlitec massmailer based on phpmailer" : [ "phpmailer.png" , "http://phpmailer.codeworxtech.com/" ] ,
  "beer email by beeradvocate.com" : [ "beeradvocate.png" , "http://beeradvocate.com/" ] ,
  "bynari insight connector" : [ "insight-connector.png" , "http://www.bynari.net/" ] ,
  "blue shield mail server" : [ "tumbleweed.png" , "http://www.tumbleweed.com/" ] ,
  "bueroware mailclient" : [ "softengine.png" , "http://www.softengine.de/" ] ,
  "billing@disputo.com" : [ "disputo_com.png" , "http://www.disputo.com/" ] ,
  "bbsoft mail server" : [ "bbsoft.png" , "http://www.bbsoft.de/" ] ,
  "brezosoft kmailer" : [ "kmailer.png" , "http://www.kmailer.com/" ] ,
  "bookcrossing.com" : [ "bookcrossing.png" , "http://www.bookcrossing.com/" ] ,
  "blue world lasso" : [ "lasso.png" , "http://www.lassosoft.com/" ] ,
  "blue sky factory" : [ "blueskyfactory.png" , "http://www.blueskyfactory.com/" ] ,
  "beatware mail-it" : [ "beos_beatwaremailit.png" , "http://www.beatware.com/" ] ,
  "balticdatacenter" : [ "balticdatacenter.png" , "http://www.balticdatacenter.pl/" ] ,
  "britecastmailer" : [ "britemoon.png" , "http://www.britemoon.com/" ] ,
  "booklooker-mail" : [ "booklooker.png" , "http://www.booklooker.de/" ] ,
  "blizzard mailer" : [ "blizzard.png" , "http://www.blizzard.com/" ] ,
  "benchmail agent" : [ "benchmark.png" , "http://benchmail.benchmark.fr/" ] ,
  "bank of america" : [ "bankofamerica.png" , "https://wealthmanagement.bankofamerica.com/nsm/demo/estatements.html" ] ,
  "bre massmailer" : [ "bre.png" ] ,
  "burgerking.de" : [ "burgerking.png" , "http://www.burgerking.de/" ] ,
  "broadcasthtml" : [ "broadcasthtml.png" , "http://www.mailworkz.com/broadcast.htm" ] ,
  "boardsolution" : [ "boardsolution.png" , "http://www.boardsolution.de/" ] ,
  "bayt sendmail" : [ "bayt.png" , "http://www.bayt.com/" ] ,
  "bronto mail" : [ "brontomail.png" , "http://www.bronto.com/" ] ,
  "bpm beeline" : [ "bpm_beeline.png" , "http://www.bpm.ch/Produkte/beeline" ] ,
  "bplaced.net" : [ "bplaced_net.png" , "http://www.bplaced.net/" ] ,
  "bitdefender" : [ "bitdefender.png" , "http://www.bitdefender.com/" ] ,
  "bluedragon" : [ "bluedragon.png" , "http://www.newatlanta.com/products/bluedragon/" ] ,
  "bestarmail" : [ "willcom.png" , "http://www.willcom-inc.com/" ] ,
  "bee alerts" : [ "bee_alerts.png" ] ,
  "basemailer" : [ "basemailer.png" ] ,
  "bas mailer" : [ "bas-mailer.png" , "http://www.pilodata.de/bas.jsp" ] ,
  "bossmedia" : [ "bossmedia.png" , "http://www.bossmedia.com/" ] ,
  "bofh-mail" : [ "bofhmail.png" ] ,
  "blitzmail" : [ "blitzmail.png" , "http://www.dartmouth.edu/comp/support/library/software/email/blitzmail/" ] ,
  "bigsender" : [ "bigsender.png" , "http://www.craigrichards.com/software/bigsender/" ] ,
  "beos-pynr" : [ "beos.png" , "http://www.beincorporated.com/" ] ,
  "beos mail" : [ "beos_bemail.png" , "http://sourceforge.net/projects/bemaildaemon/" ] ,
  "bdoc-edit" : [ "bdoc-edit.png" , "http://www.bdoc.com/" ] ,
  "boldchat" : [ "bold.png" , "http://www.boldchat.com/" ] ,
  "blink.pl" : [ "blink_pl.png" , "http://www.blink.pl/" ] ,
  "birdigee" : [ "birdigee.png" , "http://www.birdigee.de/newsletter.shtml" ] ,
  "betanews" : [ "betanews.png" ] ,
  "banan.cz" : [ "banan_cz.png" , "http://webmail.banan.cz/" ] ,
  "buch24 " : [ "buch24_de.png" , "http://www.buch24.de/" ] ,
  "bluewin" : [ "bluewin_ch.png" , "http://www.bluewin.ch/" ] ,
  "bluetie" : [ "bluetie.png" , "http://www.bluetie.com/" ] ,
  "bloomba" : [ "bloomba.png" , "http://www.statalabs.com/" ] ,
  "blog.de" : [ "blog_de.png" , "http://www.blog.de/" ] ,
  "baur-nl" : [ "baur-nl.png" , "http://www.baur.de/" ] ,
  "basilix" : [ "basilix.png" , "http://www.basilix.org/" ] ,
  "b1gmail" : [ "b1gmail.png" , "http://www.b1g.de/" ] ,
  "bytec " : [ "bytec.png" , "http://www.bytec.biz/" ] ,
  "biabam" : [ "biabam.png" ] ,
  "bemail" : [ "beos_bemail.png" , "http://sourceforge.net/projects/bemaildaemon/" ] ,
  "becky!" : [ "becky.png" , "http://www.rimarts.co.jp/becky.htm" ] ,
  "bazaar" : [ "bazaar.png" , "http://bazaar-vcs.org/" ] ,
  "boxee" : [ "boxee.png" , "http://www.boxee.tv/" ] ,
  "bmail" : [ "bmail.png" , "http://www.beyondlogic.org/" ] ,
  "barca" : [ "barca.png" , "http://www.pocosystems.com/" ] ,
  "balsa" : [ "balsa.png" , "http://balsa.gnome.org/" ] ,
  "bscw" : [ "bscw.png" , "http://public.bscw.de/" ] ,
  "blat" : [ "blat.png" , "http://www.blat.net/" ] ,
  "beam" : [ "beos_beam.png" , "http://beam.sourceforge.net/" ] ,
  "bbc" : [ "bbc.png" , "http://www.bbc.co.uk/" ] ,
}
